@@ -13,17 +13,18 @@
   # Sys.setenv() replaces Sys.putenv() from R v2.5.0. Code for migration.
   if (!exists("Sys.setenv", mode="function", envir=baseenv())) {
     # To please R CMD check on R (>= 2.15.0)
-    Sys.putenv <- NULL; rm("Sys.putenv"); 
+    Sys.putenv <- NULL; rm("Sys.putenv");
     assign("Sys.setenv", Sys.putenv, pos=pos);
   }
 
-  packageStartupMessage(getName(pkg), " v", getVersion(pkg), " (", 
-    getDate(pkg), ") successfully loaded. See ?", pkgname, " for help.");
+  startupMessage(pkg);
 }
 
 
 ############################################################################
 # HISTORY:
+# 2013-04-15
+# o Now utilizing startupMessage() of Package in R.oo.
 # 2010-11-02
 # o Added a workaround for an R (>= 2.15.0) CMD check NOTE.
 # 2011-09-24
